@@ -1,6 +1,6 @@
 package Bio::DB::Bam::Alignment;
 
-# $Id: Alignment.pm 22684 2010-02-09 18:22:23Z lstein $
+# $Id: Alignment.pm 22740 2010-02-25 21:49:41Z lstein $
 
 =head1 NAME
 
@@ -534,7 +534,7 @@ sub padded_alignment {
     my ($pad_source,$pad_target,$pad_match);
     for my $event (@$cigar) {
 	my ($op,$count) = @$event;
-	if ($op eq 'I' || $op eq 'S' || $op eq 'H') {
+	if ($op eq 'I' || $op eq 'S') {
 	    $pad_source .= '-' x $count;
 	    $pad_target .= substr($tdna,0,$count,'');
 	    $pad_match  .= ' ' x $count;
@@ -543,6 +543,9 @@ sub padded_alignment {
 	    $pad_source .= substr($tdna,0,$count,'');
 	    $pad_target .= '-' x $count;
 	    $pad_match  .= ' ' x $count;
+	}
+	elsif ($op eq 'H') {
+	    # nothing needs to be done in this case
 	} else {  # everything else is assumed to be a match -- revisit
 	    $pad_source .= substr($sdna,0,$count,'');
 	    $pad_target .= substr($tdna,0,$count,'');
